#
# spec file for package rofi
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           rofi
Version:        1.2.0
Release:        2.3
Summary:        A window switcher, run dialog and dmenu replacement
License:        MIT
Group:          System/GUI/Other
Url:            https://davedavenport.github.io/rofi/
Source:         https://github.com/DaveDavenport/%{name}/releases/download/%{version}/%{name}-%{version}.tar.gz
Patch0:         xdg-terminal.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  cairo-devel
BuildRequires:  libxkbcommon-devel
BuildRequires:  libxkbcommon-x11-devel
BuildRequires:  make
BuildRequires:  pango-devel
BuildRequires:  startup-notification-devel
BuildRequires:  xcb-util-devel
BuildRequires:  xcb-util-wm-devel
BuildRequires:  xcb-util-xrm-devel
Requires:       xdg-utils
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
A popup window switcher roughly based on superswitcher, requiring only xlib and pango. This version started off as a clone of simpleswitcher, the version from Sean Pringle. All credit for this great tool should go to him. Rofi developed extra features, like a run-dialog, ssh-launcher and can act as a drop-in dmenu replacement, making it a very versatile tool.

%prep
%setup -q
%patch0 -p1

%build
%configure
make %{?_smp_mflags}

%install
make %{?_smp_mflags} DESTDIR=%{buildroot} install

%files
%defattr(-,root,root)
%doc Changelog README.md COPYING
%{_bindir}/rofi
%{_bindir}/rofi-sensible-terminal
%{_mandir}/man1/rofi.1.gz
%{_mandir}/man1/rofi-sensible-terminal.1.gz

%changelog
* Wed Sep  7 2016 mvetter@suse.com
- Update to version 1.2.0:
  New Features
  * Highlight matched part of the string.
  * Make window switcher string customizable.
  Improvements
  * Improved selection mode in dmenu with selection counter.
  * Improved selection mode with 'dot' indicator.
  * Fix Current Desktop window switcher.
  * Fix  launching in terminal.
  * Supports include in config.
  * Add Control+k remove till eol keybinding.
  * Change clear line to Control+w and make Control+u remove till sol (matching readline)
  * Track origin of option value e.g. who set the option.
  * Comment default values in dump-xresources.
  * Fix displaying on 30bit 10bpc X setup.
  Removals:
  * Remove xlib dependency (xcb-xrm)
  * Remove fuzzy option
  * Remove i3 workaround as it no longer needed since I3 v4.9. (Feb. 2015)
- Remove BuildRequire xorg-x11-devel in favour of xcb-util-xrm-devel
* Thu Jun 16 2016 mvetter@suse.com
- Fix typo in xdg-terminal.patch
* Thu Jun 16 2016 mvetter@suse.com
- Update to version 1.1.0:
  New Features
  * Keys mode, showing keybindings.
  * Stop cycling option (#407) (Thx to Yaroslav)
  * Kill window on delete entry (#316)
  Improvements
  * Add Control+Backspace as remove word back keybinding.
  * Allow user to use X11 background for fake transparency (#390)
  * Allow user to specify background image.
  * Improved keybinding handling, allowing on-release and modifier only (#384).
  * Use display name for prompt (#409)
  * Parse subdirectories in drun parser (#416)
  * Switch to stop cycling (#407)
  Bug fixes
  * Grab mouse pointer with keyboard
- Update xdg-terminal.patch to match
* Thu May 12 2016 mvetter@suse.com
- Update to version 1.0.1
  * Fix typo in manpage.
  * Return old behaviour for rofi placement (#395, #389)
  * Switch desktop when switching window (#393)
  * Remove unneeded use of bash (#391)
  * Make history parser more robust against corrupted files. (#388)
  * Fix desktop number (#386)
* Tue Apr 19 2016 mvetter@suse.com
- Update to version 1.0.0
- Uses xcb instead of xlib now
    New Features:
  * Blinking cursor
  * Separate configuration file
  * History in drun mode (#343)
  * Context menu mode, show rofi at the mouse pointer
    Improvement:
  * auto select and single item on dmenu mode (#281)
  * Unlimited window title length.
  * Correctly follow the active desktop, instead of active window.
  * If requesting modi that is not enabled, show it anyway.
  * DMenu password mode. (#315)
  * Levenshtein sort is now UTF-8 aware.
  * Use xcb instead of large xlib library.
  * Use GLib mainloop for cleaner code and easier external event based handling in future.
  * Run dialog: Try to convert between locale, fs encoding and utf8. Fixing problems with non-utf8 filesystem encodings.
  * Try to display non-utf8 strings as good as possible.
  * Autocomplete bang hint in combi mode (#380)
  * Remove magic line length limits by switching to getline from fgets.
  * Print git version for git builds in version string.
  Bug fixes:
  * Fix subpixel rendering. (#303)
  * Fix basic tests on OpenBSD (#272)
  * Fix wrong use of memcpy (thx to Jasperia).
  * Work around for sigwaitinfo on OpenBSD.
  * Ignore invalid entries (non-utf8) in dmenu mode.
  * Glib signal handling.
  * Fix connecting to i3 on bsd.
  * Be able to distinguish between empty and cancel in dmenu mode. (#323)
  * Fix memcpy on single memory region. (#312)
  * Fix opening file with mode a+ and using fseek to overwrite on bsd.
  Regressions
  * Removal of old themeing method. Given it was incomplete.
  * Removal of daemon mode, given this duplicates Window Manager functionality.
* Mon Mar  7 2016 mvetter@suse.com
- Update to version 0.15.12
  * keyboard layout bugfixes
  * speedups for dmenu reading
  * multi core
  * better themes support
  * a lot more
- Remove 0001-Replace-x-terminal-emulator-with-xdg-terminal.patch:
  and add xdg-terminal.patch: using xdg-terminal
* Tue Aug  4 2015 mvetter@suse.com
- Add patch 0001-Replace-x-terminal-emulator-with-xdg-terminal.patch
  to use xdg-terminal instead of x-terminal-emulator.
* Tue Jul 28 2015 mvetter@suse.com
- Initial package for version 0.15.7.
